@@ -7,8 +7,7 @@
 	ier = grgmem (size,pointer)
 
   where : size is an integer size of memory to allocate
-	  pointer is an integer (integer*8 on some systems)
-           to return the pointer into
+	  pointer is an integer to return the pointer into
 
 */
 
@@ -21,12 +20,11 @@
 #endif
 
 int GRGMEM(size, pointer)
-int *size;
-void **pointer;
+int *size, *pointer;
 {
-  *pointer = malloc(*size);
-  /* printf("grgmem: %d %p\n", *size, *pointer); */
-  if (*pointer == NULL) return 0;
+  char *area = malloc(*size);
+  *pointer = (int)area;
+  if (area == NULL) return 0;
   return 1;
 }
 
@@ -42,10 +40,9 @@ void **pointer;
 */
 
 int GRFMEM(size, pointer)
-int *size;
-void **pointer;
+int *size, *pointer;
 {
-  free(*pointer);
+  char *area = (char *)*pointer;
+  free(area);
   return 1;
 }
-
